PyXMake Developer Guide: PyXMake.API.Backend Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Public Member Functions | Public Attributes | List of all members
PyXMake.API.Backend Class Reference

Class instance to define PyXMake's web API instance. More...

Inheritance diagram for PyXMake.API.Backend:

## Public Member Functions
| __init__ (self, *args, **kwargs)
Public Member Functions inherited from PyXMake.Tools.Utility.AbstractBase
| __new__ (cls, *args, **kwargs)
| recover (cls, *args)
| classify (cls, *args, **kwargs)
| jsonify (self)
| update (self, **kwargs)
| __repr__ (self)
| __str__ (self)
| __getstate__ (self)
| __setstate__ (self, _dict)

## Public Attributes
str | APIObjectKind = "Backend"
| APIBase

## Additional Inherited Members
Static Public Member Functions inherited from PyXMake.Tools.Utility.AbstractBase
| __getbase__ (base, cls)

## Detailed Description

Class instance to define PyXMake's web API instance.

    Class instance to define PyXMake's server instance for a web API.

## Constructor & Destructor Documentation

## ◆ __init__()

PyXMake.API.Backend.__init__ | ( |  | self,
|  | * | args,
|  | ** | kwargs )

    Initialization of PyXMake's Backend API.

Reimplemented from PyXMake.Tools.Utility.AbstractBase.

Reimplemented in PyXMake.API.Frontend.

Definition at line 147 of file __init__.py.

## Member Data Documentation

## ◆ APIBase

PyXMake.API.Backend.APIBase

Definition at line 337 of file __init__.py.

## ◆ APIObjectKind

PyXMake.API.Backend.APIObjectKind = "Backend"

Definition at line 156 of file __init__.py.

The documentation for this class was generated from the following file:

- src/PyXMake/API/__init__.py